#
# spec file for package python-easy-thumbnails
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-easy-thumbnails
Version:        2.8.5
Release:        1.6
Summary:        Easy thumbnails for Django
License:        BSD-2-Clause
URL:            https://github.com/SmileyChris/easy-thumbnails
Source:         https://files.pythonhosted.org/packages/source/e/easy-thumbnails/easy-thumbnails-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-Pillow
Requires:       python-lxml
Requires:       python-reportlab
Requires:       python-svglib
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module cssselect2}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module reportlab}
BuildRequires:  %{python_module svglib}
# /SECTION
%python_subpackages

%description
The powerful, yet easy to implement thumbnailing application for Django.

%prep
%setup -q -n easy-thumbnails-%{version}
sed -i '1 { /^#!/ d }' easy_thumbnails/tests/mock*.py
dos2unix README.rst

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# this runs 119 tests, which pyunittest or pytest won't make
export DJANGO_SETTINGS_MODULE='easy_thumbnails.tests.settings'
export PYTHONPATH=${PWD}
%python_exec -m django test -v 2

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Jan 13 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.5:
  * Fix regression introduced in version 2.8.4. Argument ``quality`` is not
    removed for images of type ``.webp``.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.4:
  * Fix problem when thumbnailing images of type TIFF. PIL's
    ``TiffImagePlugin`` doesn't like argument ``quality``.
  * Replace deprecated Pillow constants against newer counterparts. Check
  https://pillow.readthedocs.io/en/stable/releasenotes/9.1.0.html#deprecations for details.
* Fri Dec 24 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.8
  * Add support for thumbnailing SVG images.
- from v2.7.2
  * Add support for Django 3.2 and Python-3.10.
  * Do not close image after loading content.
  * In management command thumbnail_cleanup, replace print-statements
    against stdout.write.
  * Use Python format strings whereever possible.
- from v2.7.1
  * Add support for Django 3.1
* Thu Oct 14 2021 pgajdos@suse.com
- %%check: do not use setup.py test
* Tue Dec 31 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.7
* Wed Jan 23 2013 alexandre@exatati.com.br
- Update to 1.2:
  * Django 1.5 compatibility.
  * Fixed a problem with the ImageClearableFileInput widget.
* Wed Aug 29 2012 alexandre@exatati.com.br
- Update to 1.1:
  * Added a way to avoid generating thumbnails if they don't exist
    already (with a signal to deal with them elsewhere).
  * Added a thumbnailer_passive filter to allow templates to use the
    non-generating thumbnails functionality when dealing with aliases.
* Wed May 30 2012 alexandre@exatati.com.br
- Update to 1.0.3:
  - Changed the exception to catch from 1.0.2 to IOError.
* Mon May 28 2012 alexandre@exatati.com.br
- Update to 1.0.2:
  - Catch an OSError exception when trying to get the EXIF data of
    a touchy image.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 1.0-alpha-21:
  - Sorry, no changelog.
* Wed Dec  7 2011 alexandre@exatati.com.br
- Update to 1.0-alpha-20:
  - Sorry, no changelog.
* Tue Dec  6 2011 alexandre@exatati.com.br
- Update to 1.0-alpha-19:
  - Sorry, no changelog.
- Regenerate spec file with py2pack.
* Thu Nov  4 2010 alexandre@exatati.com.br
- Initial package (1.0-alpha-13) for openSUSE.
